import React, { useState } from "react";

import { useSelector } from "react-redux";

import SyntaxHighlighter from "react-syntax-highlighter";
import { monoBlue } from "react-syntax-highlighter/dist/esm/styles/hljs";
import { inline } from "./code.js";

import { Card, Row, Col, Menu, Button } from "antd";
import { RiMailLine, RiCodeSSlashLine } from "react-icons/ri";

const { SubMenu } = Menu;

export default function InlineMenu() {
  const [checkedCode, setCheckedCode] = useState(false);
  const [codeClass, setCodeClass] = useState(false);

  function toggleChecked() {
    setTimeout(() => setCodeClass(!codeClass), 100);
    setCheckedCode(!checkedCode);
  }

   // Redux
  const customise = useSelector(state => state.customise)

  return (
    <Card className="hp-border-color-black-40">
      <Row>
        <Col span={24}>
          <Row>
            <Col lg={12} span={20}>
              <h4>Inline Menu</h4>
              <p className="hp-p1-body">Vertical menu with inline submenus.</p>
            </Col>

            <Col lg={12} span={4} className="hp-text-right">
              <Button
                onClick={toggleChecked}
                type="text"
                icon={<RiCodeSSlashLine className="hp-text-color-black-80" />}
              />
            </Col>
          </Row>
        </Col>

        <Col span={24}>
          <Menu
            defaultSelectedKeys={["1"]}
            defaultOpenKeys={["sub1"]}
            mode="inline"
            theme={customise.theme == "light" ? "light" : "dark"}
          >
            <SubMenu
              key="sub1"
              icon={<RiMailLine className="remix-icon" />}
              title="Navigation One"
            >
              <Menu.ItemGroup key="g1" title="NAVIGATION GROUP">
                <Menu.Item key="1">Option 1</Menu.Item>
                <Menu.Item key="2">Option 2</Menu.Item>
              </Menu.ItemGroup>

              <Menu.ItemGroup key="g2" title="NAVIGATION GROUP">
                <Menu.Item key="3">Option 3</Menu.Item>
                <Menu.Item key="4">Option 4</Menu.Item>
              </Menu.ItemGroup>
            </SubMenu>

            <SubMenu
              key="sub2"
              icon={<RiMailLine className="remix-icon" />}
              title="Navigation Two"
            >
              <Menu.Item key="5">Option 5</Menu.Item>
              <Menu.Item key="6">Option 6</Menu.Item>

              <SubMenu key="sub3" title="Submenu">
                <Menu.Item key="7">Option 7</Menu.Item>
                <Menu.Item key="8">Option 8</Menu.Item>
              </SubMenu>
            </SubMenu>

            <SubMenu
              key="sub4"
              icon={<RiMailLine className="remix-icon" />}
              title="Navigation Three"
            >
              <Menu.Item key="9">Option 9</Menu.Item>
              <Menu.Item key="10">Option 10</Menu.Item>
              <Menu.Item key="11">Option 11</Menu.Item>
              <Menu.Item key="12">Option 12</Menu.Item>
            </SubMenu>
          </Menu>
        </Col>
      </Row>

      {checkedCode && (
        <SyntaxHighlighter
          language="javascript"
          className={`show-code hp-mt-24 ${codeClass && "show-code-active"}`}
          style={monoBlue}
        >
          {inline}
        </SyntaxHighlighter>
      )}
    </Card>
  );
}
